@@ -7,10 +7,10 @@
 
 int main(void) {
     newtComponent b1, b2, b3, b4;
-    newtComponent answer, f, t;
+    newtComponent f, t;
     newtGrid grid, subgrid;
     char * flowedText;
-    int textWidth, textHeight, rc;
+    int textWidth, textHeight, rc, i;
     char * menuContents[] = { "One", "Two", "Three", "Four", "Five", NULL };
     char * entries[10];
     struct newtWinEntry autoEntries[] = {
@@ -45,7 +45,7 @@ int main(void) {
     newtGridWrappedWindow(grid, "first window");
     newtGridFree(grid, 1);
 
-    answer = newtRunForm(f);
+    newtRunForm(f);
 	
     newtFormDestroy(f);
     newtPopWindow();
@@ -79,7 +79,7 @@ int main(void) {
 
     f = newtForm(NULL, NULL, 0);
     newtFormAddComponents(f, b1, t, b2, NULL);
-    answer = newtRunForm(f);
+    newtRunForm(f);
 
     newtPopWindow();
     newtFormDestroy(f);
@@ -97,6 +97,8 @@ int main(void) {
 		     "newtWinEntries() call. It lets you get a lot of input "
 		     "quite easily.", 50, 5, 5, 20, autoEntries, "Ok", 
 		     "Cancel", NULL);
+    for (i = 0; i < sizeof (autoEntries) / sizeof (struct newtWinEntry) && autoEntries[i].value; i++)
+	    free(*(autoEntries[i].value));
 
     newtFinished();
 
